@@ -19,11 +19,6 @@ pub struct ChapterAttributes {
     pub chapter: Option<String>,
     /// Language the text is in.
     pub translated_language: Language,
-    pub hash: String,
-    /// Original upload quality filenames.
-    pub data: Vec<String>,
-    /// Compressed quality filenames.
-    pub data_saver: Vec<String>,
     /// User ID (UUID) who uploaded the chapter.
     pub uploader: Option<Uuid>,
     /// While `hash`, `data` and `dataSaver` attributes are empty,
